RuleEngine

Struct RuleEngine 

pub struct RuleEngine<'a> {
    pub knowledge: HashMap<String, String>,
    pub rules: Vec<Rule<'a>>,
}
Defines an engine used to evaluate and execute rules.

Fields

knowledge: HashMap<String, String>rules: Vec<Rule<'a>>

Implementations

Source

impl RuleEngine<'_>

pub fn new( knowledge: HashMap<String, String>, rules: Vec<Rule<'_>>, ) -> RuleEngine<'_>

creates a new instance of RuleEngine

pub fn run(&mut self) -> Result<bool, RuleError>

orders rules by their priority, evaluates their conditions, and if true, executes the action.